"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInOutTransition = exports.TransitionStage = void 0;
const react_1 = require("react");
var TransitionStage;
(function (TransitionStage) {
    TransitionStage["entering"] = "entering";
    TransitionStage["entered"] = "entered";
    TransitionStage["exiting"] = "exiting";
    TransitionStage["exited"] = "exited";
    TransitionStage["appear"] = "appear";
})(TransitionStage = exports.TransitionStage || (exports.TransitionStage = {}));
function useInOutTransition(value, duration) {
    const [state, setState] = (0, react_1.useState)(value ? TransitionStage.appear : TransitionStage.exited);
    const isInitialRun = (0, react_1.useRef)(true);
    const durationRef = (0, react_1.useRef)(duration);
    durationRef.current = duration; // use latest
    (0, react_1.useEffect)(() => {
        if (isInitialRun.current) {
            isInitialRun.current = false;
            return () => { };
        }
        setState(value ? TransitionStage.entering : TransitionStage.exiting);
        const tmId = setTimeout(() => {
            const next = value ? TransitionStage.entered : TransitionStage.exited;
            setState(next);
        }, durationRef.current);
        return () => clearTimeout(tmId);
    }, [value]);
    return state;
}
exports.useInOutTransition = useInOutTransition;
//# sourceMappingURL=use-in-out-transition.js.map